==> vegafusion_python_embed-1.0.2.tar.gz: vegafusion_python_embed-1.0.2/local_dependencies/vegafusion-rt-datafusion/tests/util/datasets.rs <==
use reqwest_middleware::ClientWithMiddleware;
use serde_json::Value;
use vegafusion_core::data::table::VegaFusionTable;
use vegafusion_rt_datafusion::data::tasks::make_request_client;

lazy_static! {
    pub static ref REQWEST_CLIENT: ClientWithMiddleware = make_request_client();
}

pub fn vega_json_dataset(name: &str) -> VegaFusionTable {
    // Remove trailing .json if present because we'll add it below
    let name = match name.strip_suffix(".json") {
        None => name,
        Some(name) => name,
    };

    // Fetch dataset from vega-datasets repository
    let body = reqwest::blocking::get(format!(
        "https://raw.githubusercontent.com/vega/vega-datasets/master/data/{}.json",
        name
    ))
    .unwrap()
    .text()
    .unwrap();
    let json_value: Value = serde_json::from_str(&body).unwrap();

    VegaFusionTable::from_json(&json_value, 1024).unwrap()
}

pub async fn vega_json_dataset_async(name: &str) -> VegaFusionTable {
    // Remove trailing .json if present because we'll add it below
    let name = match name.strip_suffix(".json") {
        None => name,
        Some(name) => name,
    };

    // Fetch dataset from vega-datasets repository
    let body = REQWEST_CLIENT
        .get(format!(
            "https://raw.githubusercontent.com/vega/vega-datasets/master/data/{}.json",
            name
        ))
        .send()
        .await
        .unwrap()
        .text()
        .await
        .unwrap();
    let json_value: Value = serde_json::from_str(&body).unwrap();

    VegaFusionTable::from_json(&json_value, 1024).unwrap()
}

==> vegafusion_python_embed-1.0.4.tar.gz: vegafusion_python_embed-1.0.4/local_dependencies/vegafusion-rt-datafusion/tests/util/datasets.rs <==
use reqwest_middleware::ClientWithMiddleware;
use serde_json::Value;
use vegafusion_core::data::table::VegaFusionTable;
use vegafusion_rt_datafusion::data::tasks::make_request_client;

lazy_static! {
    pub static ref REQWEST_CLIENT: ClientWithMiddleware = make_request_client();
}

pub fn vega_json_dataset(name: &str) -> VegaFusionTable {
    // Remove trailing .json if present because we'll add it below
    let name = match name.strip_suffix(".json") {
        None => name,
        Some(name) => name,
    };

    // Fetch dataset from vega-datasets repository
    let body = reqwest::blocking::get(format!(
        "https://raw.githubusercontent.com/vega/vega-datasets/master/data/{name}.json"
    ))
    .unwrap()
    .text()
    .unwrap();
    let json_value: Value = serde_json::from_str(&body).unwrap();

    VegaFusionTable::from_json(&json_value, 1024).unwrap()
}

pub async fn vega_json_dataset_async(name: &str) -> VegaFusionTable {
    // Remove trailing .json if present because we'll add it below
    let name = match name.strip_suffix(".json") {
        None => name,
        Some(name) => name,
    };

    // Fetch dataset from vega-datasets repository
    let body = REQWEST_CLIENT
        .get(format!(
            "https://raw.githubusercontent.com/vega/vega-datasets/master/data/{name}.json"
        ))
        .send()
        .await
        .unwrap()
        .text()
        .await
        .unwrap();
    let json_value: Value = serde_json::from_str(&body).unwrap();

    VegaFusionTable::from_json(&json_value, 1024).unwrap()
}
